@@ -1,5 +1,8 @@
 #![cfg(feature = "full")]
-use std::{sync::Arc, time::Duration};
+use std::{
+    sync::{atomic::AtomicI64, Arc},
+    time::Duration,
+};
 
 use async_trait::async_trait;
 use bytes::{BufMut, BytesMut};
